@@ -1,15 +1,40 @@
-///////////////////////////////////////////////////////////////////////////
-// $Id: managementWidget.cpp,v 1.52 2001/07/20 14:55:35 toivo Exp $	
-// File  : managementWidget.cpp
+/* managementWidget.cpp
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
 //
 // See managementWidget.h for more information
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 
 #include <qsplitter.h>
-#include <qstack.h>
+#include <qptrstack.h>
 
 #include <klocale.h>
+#include <kdebug.h>
 
 // kpackage.headers
 #include "kpackage.h"
@@ -27,12 +52,11 @@ extern Opts *opts;
 managementWidget::managementWidget(QWidget *parent)
   : QFrame(parent)
 {
-  install_action=0;
-  uninstall_action=0;
-  package=0;
+  install_action = 0;
+  uninstall_action = 0;
 
-  allPackages  = new QList<packageInfo>;
-  QStack<QString> stack();
+  allPackages  = new QPtrList<packageInfo>;
+  QPtrStack<QString> stack();
 
   tType[0] = i18n("Installed");
   tType[1] = i18n("Updated");
@@ -42,7 +66,11 @@ managementWidget::managementWidget(QWidget *parent)
   dirInstPackages = new QDict<packageInfo>(7717);
   dirUninstPackages = new QDict<packageInfo>(7717);
   dirInfoPackages = new QDict<packageInfo>(7717);
+
   setupWidgets();
+
+  connect(treeList,SIGNAL(updateMarked()), 
+	  this, SLOT( checkMarked()));
 }
 
 managementWidget::~managementWidget()
@@ -97,7 +125,7 @@ void managementWidget::setupWidgets()
 
   for (int i = 0; i < 4; i++) {
     QTab *t = new QTab();
-    t->label = tType[i];
+    t->setText( tType[i] );
     ltab->addTab(t);
   }
   connect(ltab,SIGNAL(selected (int)),SLOT(tabChanged(int)));
@@ -112,12 +140,12 @@ void managementWidget::setupWidgets()
 
   lbuttons = new QBoxLayout(QBoxLayout::LeftToRight);
 
-  luinstButton = new QPushButton(i18n("Uninstall marked"),leftpanel);
-  luinstButton->setEnabled(TRUE);
+  luinstButton = new QPushButton(i18n("Uninstall Marked"),leftpanel);
+  luinstButton->setEnabled(FALSE);
   connect(luinstButton,SIGNAL(clicked()),
 	  SLOT(uninstallMultClicked()));
-  linstButton = new QPushButton(i18n("Install marked"),leftpanel);
-  linstButton->setEnabled(TRUE);
+  linstButton = new QPushButton(i18n("Install Marked"),leftpanel);
+  linstButton->setEnabled(FALSE);
   connect(linstButton,SIGNAL(clicked()),
 	  SLOT(installMultClicked()));
 
@@ -136,10 +164,8 @@ void managementWidget::setupWidgets()
   rightbox = new QBoxLayout(rightpanel,QBoxLayout::TopToBottom);
 
   packageDisplay = new packageDisplayWidget(rightpanel);
-  //  packageDisplay->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-  //  packageDisplay->setLineWidth(2);
-  connect(this, SIGNAL(changePackage(packageInfo *)),
-	  packageDisplay, SLOT(changePackage(packageInfo *)));
+  //  connect(this, SIGNAL(changePackage(packageInfo *)),
+  //  packageDisplay, SLOT(changePackage(packageInfo *)));
 
   rbuttons = new QBoxLayout(QBoxLayout::LeftToRight);
 
@@ -161,6 +187,7 @@ void managementWidget::setupWidgets()
   rbuttons->addWidget(instButton,1);
   rbuttons->addWidget(uinstButton,1);
   rbuttons->addStretch(1);
+
 }
 
 ////////////////////////////////////////////////////////////////
@@ -209,23 +236,35 @@ void managementWidget::readTreeType()
 }
 
 ///////////////////////////////////////////////////////////////////
+void managementWidget::setupMultButton()
+{
+  if (cntInstall)
+    linstButton->setEnabled(true);
+  else
+    linstButton->setEnabled(false);
+
+  if (cntUnInstall)
+    luinstButton->setEnabled(true);
+  else
+    luinstButton->setEnabled(false);
+}
+
 void managementWidget::setupInstButton()
 {
   bool u,i;
-  if (!package)
-  {
+
+  packageInfo *package = packageDisplay->package;
+
+  if (!package) {
     i = false;
     u = false;
-  }
-  else
-  {
-    if (package->interface->noFetch || !package->getFilename().isEmpty() ) {
+  } else {
+    if (package->isFetchable() ) {
       instButton->setText(i18n("Install"));
     } else {
       instButton->setText(i18n("Fetch"));
     }
-    if (package->packageState != packageInfo::INSTALLED &&
-        !package->getProperty("filename").isNull() ) {
+    if (package->isInstallable() ) {
 
       i = true;
       u = false;
@@ -240,7 +279,7 @@ void managementWidget::setupInstButton()
 
   uinstButton->setEnabled(u);
   if (uninstall_action)
-     uninstall_action->setEnabled(u);
+    uninstall_action->setEnabled(u);
 }
 
 void managementWidget::arrangeWidgets()
@@ -275,14 +314,14 @@ void managementWidget::collectData(bool refresh)
   connect(treeList, SIGNAL(selectionChanged(QListViewItem *)),
 	  SLOT(packageHighlighted(QListViewItem *)));
 
-  packageDisplay->noPackage();
+  packageDisplay->changePackage(0);
 
   // Delete old list if necessary
   if(allPackages) {
     delete allPackages;
   }
 
-  allPackages = new QList<packageInfo>;
+  allPackages = new QPtrList<packageInfo>;
   allPackages->setAutoDelete(TRUE);
 
   dirInstPackages->clear();
@@ -290,7 +329,9 @@ void managementWidget::collectData(bool refresh)
   // List installed packages
   for (i = 0; i < kpinterfaceN; i++)  {
     if (kpinterface[i] && opts->handlePackage[i]) {
-      kpinterface[i]->listPackages(allPackages);
+      if (hostName.isEmpty() || (kpinterface[i]->hasRemote)) {
+	kpinterface[i]->listPackages(allPackages);
+      }
     }
   }
 
@@ -309,35 +350,42 @@ void managementWidget::rebuildListTree()
   kpackage->setStatus(i18n("Building package tree"));
   kpackage->setPercent(0);
 
+  treeList->setSorting(-1);
 
   // place all the packages found
   int count = allPackages->count();
+  int incr = count/50;
+  if (incr == 0)
+    incr = 1;
 
   for(i=allPackages->first(); i!=0; i=allPackages->next())
     {
       i->place(treeList,TRUE);
 
-      int num = (n*100)/count;
-      if (!(num % 5))
-	kpackage->setPercent(num);
+      if (!(n % incr)) {
+	kpackage->setPercent(int (n*100/count));
+      }
       n++;
     }
   treeList->show();		// show the list tree
   sweep();
+
+  treeList->setSorting(0);
+
   kpackage->setPercent(100);	// set the progress
+  kpackage->setStatus("");
+
+  checkMarked();
 }
 
 // A package has been highlighted in the list tree
 void managementWidget::packageHighlighted(QListViewItem *item)
 {
-
   KPLVItem *sel = (KPLVItem *)item;
 
   if (!sel || sel->childCount()) {
-    emit changePackage(0);
-    package = 0;
+    packageDisplay->changePackage(0);
   } else if (sel) {
-
     if (!notPress) {
       int n = stack.at();
       int num = stack.count();
@@ -349,11 +397,9 @@ void managementWidget::packageHighlighted(QListViewItem *item)
 
     // Disable the tree list while we do this
     treeList->setEnabled(FALSE);
-    // Tell everything that is interested to change packages
-    emit changePackage(sel->info);
 
-    // Keep copy of the package
-    package = sel->info;
+    // Tell everything that is interested to change packages
+     packageDisplay->changePackage(sel->info);
 
     // Re-enable the treeList and uninstall button
     treeList->setEnabled(TRUE);
@@ -376,34 +422,43 @@ void managementWidget::packageHighlighted(QListViewItem *item)
 void managementWidget::installSingleClicked()
 {
   int result;
-  QList<packageInfo> plist;
+  QPtrList<packageInfo> plist;
+
+  packageInfo *package = packageDisplay->package;
 
   if (package) {
     QString filename = package->getFilename();
-    kdDebug() << "File=" << filename << "\n";
+    kdDebug() << "File=" << filename  <<"\n";
     pkgInterface *interface = package->interface;
     if (interface->noFetch || !filename.isEmpty()) {
       plist.append(package);
       interface->installation->setup(&plist, interface->head);
       result = interface->installation->exec();
 
-      if(result == QDialog::Accepted) { // execute it
+      if (interface->installation->result() == QDialog::Accepted ||
+	  interface->installation->modified) { 
 	// it was accepted, so the package has been installed
 	packageInfo *inf;
 	for (inf = plist.first(); inf != 0; inf = plist.next()) {
 	  updatePackage(inf,TRUE);
 	}
 
-	emit changePackage(0); // change package to no package
-	package = 0;
-        setupInstButton();
+	if (treeList->currentItem()) {
+	  KPLVItem *p = treeList->currentItem();
+	  packageDisplay->changePackage(p->info);
+	} else {
+	  packageDisplay->changePackage(0); // change package to no package
+	}
+	setupInstButton();	  
       }
+
+      //      kdDebug() << "Result=" << result <<"\n";
     } else {
       QString url = package->getUrl();
       if (!url.isEmpty()) {
 	QString s = kpackage->fetchNetFile(url);
 	if (!s.isEmpty()) {
-	  emit changePackage(package);
+	  packageDisplay->changePackage(package);
 	  setupInstButton();
 	}
       } else {
@@ -412,6 +467,8 @@ void managementWidget::installSingleClicked()
     }
   }
   kpackage->setPercent(100);
+
+  checkMarked();
 }
 
 // install has been clicked
@@ -420,13 +477,13 @@ void managementWidget::installMultClicked()
   int  i;
   KPLVItem *it;
   packageInfo *inf;
-  QList<packageInfo> **lst = new QList<packageInfo>*[kpinterfaceN];
+  QPtrList<packageInfo> **lst = new QPtrList<packageInfo>*[kpinterfaceN];
 
   selList.clear();
   findMarked(treeList->firstChild());
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
-      lst[i] = new QList<packageInfo>;
+      lst[i] = new QPtrList<packageInfo>;
       for (it = selList.first(); it != 0; it = selList.next()) {
 	if (it->info->interface == kpinterface[i] &&
 	    it->childCount() == 0 &&
@@ -444,7 +501,8 @@ void managementWidget::installMultClicked()
     if (kpinterface[i]) {
       if (lst[i]->count() > 0) {
 	kpinterface[i]->installation->setup(lst[i],kpinterface[i]->head);
-	if (kpinterface[i]->installation->exec()) {
+	if (kpinterface[i]->installation->exec() ||
+	    kpinterface[i]->installation->modified) {
 	  for (inf = lst[i]->first(); inf != 0; inf = lst[i]->next()) {
 	    updatePackage(inf,TRUE);
 	  }
@@ -454,6 +512,8 @@ void managementWidget::installMultClicked()
     }
   }
   delete [] lst;
+
+  checkMarked();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -462,7 +522,9 @@ void managementWidget::installMultClicked()
 void managementWidget::uninstallSingleClicked()
 {
   int result;
-  QList<packageInfo> plist;
+  QPtrList<packageInfo> plist;
+
+  packageInfo *package = packageDisplay->package;
 
   if (package) {			// check that there is a package to uninstall
     pkgInterface *interface = package->interface;
@@ -470,19 +532,26 @@ void managementWidget::uninstallSingleClicked()
     interface->uninstallation->setup(&plist, interface->head);
     result = interface->uninstallation->exec();
 
-    if(result == QDialog::Accepted) { // execute it
-      // it was accepted, so the package has been uninstalled
+    if(result == QDialog::Accepted ||
+       interface->installation->modified) { 
       packageInfo *inf;
       for (inf = plist.first(); inf != 0; inf = plist.next()) {
 	updatePackage(inf,FALSE);
       }
 
-      emit changePackage(0); // change package to no package
-      package = 0;
+      if (treeList->currentItem()) {
+	KPLVItem *p = treeList->currentItem();
+	packageDisplay->changePackage(p->info);
+      } else {
+	packageDisplay->changePackage(0); // change package to no package
+      }
       setupInstButton();
     }
+    //    kdDebug() << "Result=" << result <<"\n";
   }
   kpackage->setPercent(100);
+
+  checkMarked();
 }
 
 void managementWidget::uninstallMultClicked()
@@ -490,13 +559,13 @@ void managementWidget::uninstallMultClicked()
   int  i;
   KPLVItem *it;
   packageInfo *inf;
-  QList<packageInfo> **lst = new QList<packageInfo>*[kpinterfaceN];
+  QPtrList<packageInfo> **lst = new QPtrList<packageInfo>*[kpinterfaceN];
 
   selList.clear();
   findMarked(treeList->firstChild());
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
-      lst[i] = new QList<packageInfo>;
+      lst[i] = new QPtrList<packageInfo>;
       for (it = selList.first(); it != 0; it = selList.next()) {
 	if (it->info->interface == kpinterface[i] &&
 	    it->childCount() == 0 &&
@@ -514,7 +583,8 @@ void managementWidget::uninstallMultClicked()
     if (kpinterface[i]) {
       if (lst[i]->count() > 0) {
 	kpinterface[i]->uninstallation->setup(lst[i],kpinterface[i]->head);
-	if (kpinterface[i]->uninstallation->exec()) {
+	if (kpinterface[i]->uninstallation->exec()||
+	    kpinterface[i]->installation->modified ) {
 	  for (inf = lst[i]->first(); inf != 0; inf = lst[i]->next()) {
 	    updatePackage(inf,FALSE);
 	  }
@@ -524,6 +594,8 @@ void managementWidget::uninstallMultClicked()
     }
   }
   delete [] lst;
+
+  checkMarked();
 }
 
 ///////////////////////////////////////////////////////////////////////////
@@ -560,7 +632,7 @@ int  managementWidget::sweepChild(KPLVItem *it)
       } else {
 	it->show();
 	shown++;
-      }	
+      }
     }
   } while ((it = it->nextSibling()));
   return shown;
@@ -613,6 +685,7 @@ bool managementWidget::searchChild(KPLVItem *it)
   do {
     if (!searchSkip) {
       QString s = it->text(0);
+      //      kdDebug() << "s='" << s << "'='" <<  searchStr << "\n";
       if ((it->childCount() == 0) && (it->info->display(treeType)) &&
 	  (searchSubstr ? s.contains(searchStr,FALSE) : s == searchStr)) {
 	searchResult = it;
@@ -640,7 +713,7 @@ bool managementWidget::searchChild(KPLVItem *it)
 
 void managementWidget::doChangePackage(packageInfo *p)
 {
-  emit changePackage(p);
+   packageDisplay->changePackage(p);
 }
 
 ///////////////////////////////////////////////////////////////////////////
@@ -665,7 +738,7 @@ KPLVItem *managementWidget::changePack(KPLVItem *searchResult, bool push)
 
     i = searchResult;
     while ((i = i->parent())) {
-      i->setOpen(TRUE);	
+      i->setOpen(TRUE);
     }
     if (push) {
       stack.append(searchResult);
@@ -790,7 +863,7 @@ KPLVItem *managementWidget::updatePackage(packageInfo *pki, bool install)
 	    return q;
 	  }
 	}
-	
+
       } else {
 	delete pnew;
       }
@@ -812,6 +885,21 @@ void managementWidget::clearMarked(KPLVItem *item)
   }
 }
 
+void managementWidget::markAll(KPLVItem *item)
+{
+  while (item) {
+    if (item->childCount() > 0) {
+      markAll(item->firstChild());
+    }
+    else {
+      if (item->info->display(treeType)) {
+        item->setMark(true);
+      }
+    }
+    item = item->nextSibling();
+  }
+}
+
 void managementWidget::findMarked(KPLVItem *item)
 {
   while (item) {
@@ -825,6 +913,31 @@ void managementWidget::findMarked(KPLVItem *item)
   }
 }
 
+void managementWidget::checkMarked()
+{
+  cntInstall = 0;
+  cntUnInstall = 0;
+
+  countMarked(treeList->firstChild());
+  setupMultButton();
+}
+
+void managementWidget::countMarked(KPLVItem *item)
+{
+  while (item) {
+    if (item->childCount() > 0) {
+      countMarked(item->firstChild());
+    }
+    if (item->marked) {
+      if (item->info->isInstallable())
+	cntInstall++;
+      else
+	cntUnInstall++;
+    }
+    item = item->nextSibling();
+  }
+}
+
 ///////////////////////////////////////////////////////////////////////////
 void managementWidget::expandTree(KPQListView *list)
 {
