@@ -5,7 +5,7 @@
     Copyright (C) 1997-2000 Peter Putzer
                             putzer@kde.org
 
-	$Id: TopWidget.cpp,v 1.117 2003/10/07 17:08:16 aacid Exp $
+	$Id: TopWidget.cpp,v 1.121 2004/07/04 09:46:39 binner Exp $
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of version 2 of the GNU General Public License
@@ -78,7 +78,6 @@
 #include "ActionList.h"
 #include "ksv_core.h"
 #include "ksv_conf.h"
-#include "About.h"
 #include "RunlevelAuthIcon.h"
 #include "ksvdraglist.h"
 #include "Data.h"
@@ -111,7 +110,7 @@ KSVTopLevel::KSVTopLevel()
 	mToolsStartService (0L), mToolsStopService (0L),
     mToolsRestartService (0L), mToolsEditService (0L),
 
-	mOptionsTools (0L), mOptionsStatus (0L), mOptionsToggleLog (0L),
+    mOptionsToggleLog (0L),
 
     mOpenWith (0L), mOpenDefault (0L),
 
@@ -135,10 +134,10 @@ KSVTopLevel::KSVTopLevel()
 
   setCaption(false);
 
+  initStatusBar(); // order dependency
   initActions(); // order dependency
   mView = new KSVContent (mOpenWith->popupMenu(), this, "Content"); // order dependency
   initTools(); // order dependency
-  initStatusBar(); // order dependency
 
   setCentralWidget(mView);
 
@@ -172,7 +171,7 @@ KSVTopLevel::KSVTopLevel()
 
   // restore size and position
   move(mConfig->position()); // doesnt seem to work while unmapped
-  resize(mConfig->size());
+  setAutoSaveSettings();
 
   // start watching the directories
   mAuth->setCheckEnabled(true);
@@ -216,13 +215,13 @@ void KSVTopLevel::initActions ()
 
   // setup File menu
   mFileRevert = KStdAction::revert (this, SLOT (slotClearChanges()), coll);
-  mFileRevert->setText (i18n("Re&vert Configuration..."));
+  mFileRevert->setText (i18n("Re&vert Configuration"));
 
   mFileLoad = KStdAction::open (this, SLOT (load()), coll);
   mFileLoad->setText (i18n ("&Open..."));
 
   mFileSave = KStdAction::save(this, SLOT(slotAcceptChanges()), coll);
-  mFileSave->setText (i18n("&Save Configuration..."));
+  mFileSave->setText (i18n("&Save Configuration"));
 
   mFileSaveAs = KStdAction::saveAs (this, SLOT (saveAs ()), coll);
 
@@ -251,7 +250,7 @@ void KSVTopLevel::initActions ()
   mPasteAppend = KStdAction::paste (this, SLOT (pasteAppend()),
 									coll, "ksysv_paste_append");
 
-  mEditProperties = new KAction (i18n("P&roperties..."), 0,
+  mEditProperties = new KAction (i18n("P&roperties"), 0,
                                  this, SLOT(properties()),
                                  coll, "ksysv_properties");
 
@@ -262,8 +261,8 @@ void KSVTopLevel::initActions ()
   mOpenWith = new KActionMenu (i18n ("Open &With"), coll, "ksysv_open_with");
 
   // setup Settings menu
-  mOptionsTools = KStdAction::showToolbar(this, SLOT(toggleTools()), coll);
-  mOptionsStatus = KStdAction::showStatusbar(this, SLOT(toggleStatus()), coll);
+  createStandardStatusBarAction();
+  setStandardToolBarMenuEnabled(true);
   KStdAction::keyBindings (this, SLOT(configureKeys()), coll);
   KStdAction::configureToolbars (this, SLOT(configureToolbars()), coll);
   KStdAction::saveOptions(this, SLOT(saveOptions()), coll);
@@ -271,6 +270,7 @@ void KSVTopLevel::initActions ()
   mOptionsToggleLog = new KToggleAction (i18n("Show &Log"), "toggle_log", 0,
 										 this, SLOT (toggleLog()),
 										 coll, "ksysv_toggle_log");
+  mOptionsToggleLog->setCheckedState(i18n("Hide &Log"));
 
   // setup Tools menu
   mToolsStartService = new KToggleAction (i18n("&Start Service..."), "ksysv_start", 0,
@@ -290,13 +290,6 @@ void KSVTopLevel::initActions ()
                                          coll, "ksysv_edit_service");
 
   createGUI(xmlFile());
-
-  KAction* aboutKSysV = coll->action (KStdAction::stdName (KStdAction::AboutApp));
-  if (aboutKSysV)
-	{
-	  disconnect (aboutKSysV, SIGNAL (activated()), 0, 0);
-	  connect (aboutKSysV, SIGNAL (activated()), AboutDlg::self(), SLOT (show()));
-	}
 }
 
 bool KSVTopLevel::queryExit() {
@@ -306,8 +299,8 @@ bool KSVTopLevel::queryExit() {
     res = KMessageBox::warningYesNo(kapp->mainWidget(),
 				    i18n("There are unsaved changes. Are you sure you want to quit?"),
 				    i18n("Quit"),
-				    i18n("&Quit"),
-				    i18n("&Cancel"));
+				    KStdGuiItem::quit(),
+				    KStdGuiItem::cancel());
 
   }
 
@@ -323,7 +316,7 @@ void KSVTopLevel::slotClearChanges()
 				 i18n("Do you really want to revert all unsaved changes?"),
 				 i18n("Revert Configuration"),
 				 i18n("&Revert"),
-				 i18n("&Cancel")))
+				 KStdGuiItem::cancel()))
     {
       mUndoList->undoAll();
 	  mRedoList->clear();
@@ -338,8 +331,8 @@ void KSVTopLevel::slotAcceptChanges() {
 				     "make your system hang on startup.\n"
 				     "Do you wish to continue?"),
 				i18n("Save Configuration"),
-				i18n("&Save"),
-				i18n("&Cancel")))
+				KStdGuiItem::save(),
+				KStdGuiItem::cancel()))
     {
       mView->slotWriteSysV();
       initView();
@@ -496,8 +489,6 @@ void KSVTopLevel::updateRunlevelsPath ()
 
 void KSVTopLevel::slotReadConfig() {
   setLog(mConfig->showLog());
-  setStatus(mConfig->showStatus());
-  setTools(mConfig->showTools());
 }
 
 void KSVTopLevel::toggleLog() {
@@ -505,14 +496,6 @@ void KSVTopLevel::toggleLog() {
   setLog(value);
 }
 
-void KSVTopLevel::toggleStatus() {
-  setStatus ( mOptionsStatus->isChecked() );
-}
-
-void KSVTopLevel::toggleTools() {
-  setTools ( mOptionsTools->isChecked() );
-}
-
 void KSVTopLevel::saveOptions()
 {
   mConfig->writeSettings();
@@ -640,29 +623,6 @@ void KSVTopLevel::setLog (bool val)
   mView->setDisplayScriptOutput(val);
 }
 
-void KSVTopLevel::setStatus (bool val)
-{
-  if (val)
-	statusBar()->show();
-  else
-	statusBar()->hide();
-
-  mConfig->setShowStatus (val);
-  mOptionsStatus->setChecked (val);
-}
-
-void KSVTopLevel::setTools (bool val)
-{
-  if (val)
-	toolBar("mainToolBar")->show();
-  else
-	toolBar("mainToolBar")->hide();
-
-
-  mConfig->setShowTools (val);
-  mOptionsTools->setChecked (val);
-}
-
 void KSVTopLevel::writingEnabled (bool on)
 {
   mFileLoad->setEnabled(on);
@@ -1032,7 +992,6 @@ void KSVTopLevel::configureToolbars ()
 void KSVTopLevel::slotNewToolbarConfig()
 {
   createGUI (xmlFile());
-  setTools(mConfig->showTools());
 }
 
 void KSVTopLevel::dispatchEditService (bool val)
